@@ -179,7 +179,7 @@ _b(void)
     fprintf(stderr, "\nPopulate the instance domain ...\n");
     j = 1;
     for (i = 0; i < 20; i++) {
-	strncpy(nbuf, xxx, ncount+3);
+	memcpy(nbuf, xxx, ncount+3);
 	pmsprintf(nbuf, sizeof(nbuf), "%03d", ncount);
 	ncount++;
         inst = pmdaCacheStore(indom, PMDA_CACHE_ADD, nbuf, (void *)((__psint_t)(0xbeef0000+ncount)));
@@ -220,7 +220,7 @@ _b(void)
 	}
     }
     __pmdaCacheDump(stderr, indom, 0);
-    strncpy(nbuf, xxx, 11+3);
+    memcpy(nbuf, xxx, 11+3);
     pmsprintf(nbuf, sizeof(nbuf), "%03d", 11);
     fprintf(stderr, "\nHide %s ...\n", nbuf);
     inst = pmdaCacheStore(indom, PMDA_CACHE_HIDE, nbuf, NULL);
@@ -543,7 +543,7 @@ _j(void)
 
     fprintf(stderr, "\nPopulate the instance domain ...\n");
     for (i = 0; i < 20; i++) {
-	strncpy(nbuf, xxx, ncount+3);
+	memcpy(nbuf, xxx, ncount+3);
 	pmsprintf(nbuf, sizeof(nbuf), "%03d", ncount);
 	ncount++;
         inst = pmdaCacheStore(indom, PMDA_CACHE_ADD, nbuf, (void *)((__psint_t)(0xbeef0000+ncount)));
