@@ -165,6 +165,7 @@ __pmFetch(__pmContext *ctxp, int numpmid, pmID *pmidlist, __pmResult **result)
 {
     int		need_unlock = 0;
     int		ctx, sts;
+    int		i;
 
     if (pmDebugOptions.pmapi)
 	trace_fetch_entry(numpmid, pmidlist);
@@ -242,6 +243,25 @@ __pmFetch(__pmContext *ctxp, int numpmid, pmID *pmidlist, __pmResult **result)
 
 	if (newlist != NULL)
 	    free(newlist);
+	/*
+	 * pmUnregisterDerived() introduces the possibility of a stale
+	 * PMID being used in fetch => PMID 511.?.? or PM_ID_NULL passed
+	 * to PMCD which returns PM_ERR_NOAGENT, which is NQR.
+	 *
+	 * Historically PM_ID_NULL was always possible, because that's what
+	 * pmLookupName() will set the PMID to for an unknown name in the
+	 * PMNS, and PM_ERR_AGENT in this case is also misleading.
+	 *
+	 * ... remap error code PM_ERR_AGENT to PM_ERR_PMID here for these
+	 * cases if we have a valid pmResult
+	 */
+	if (sts >= 0) {
+	    for (i = 0; i < (*result)->numpmid; i++) {
+		if ((*result)->vset[i]->numval == PM_ERR_NOAGENT &&
+		    (IS_DERIVED((*result)->vset[i]->pmid) || (*result)->vset[i]->pmid == PM_ID_NULL))
+		    (*result)->vset[i]->numval = PM_ERR_PMID;
+	    }
+	}
     }
 
 pmapi_return:
