@@ -534,9 +534,11 @@ static void
 server_cache_series_finished(void *arg)
 {
     seriesLoadBaton	*baton = (seriesLoadBaton *)arg;
+#if ! defined(NDEBUG)
     seriesGetContext	*context = &baton->pmapi;
 
     assert(context->result == NULL);
+#endif
 
     /* drop load reference taken in server_cache_series */
     doneSeriesLoadBaton(baton, "server_cache_series_finished");
@@ -1162,6 +1164,10 @@ freeSeriesLoadBaton(seriesLoadBaton *baton)
 void
 doneSeriesLoadBaton(seriesLoadBaton *baton, const char *caller)
 {
+    if (baton == NULL) {
+        pmNotifyErr(LOG_ERR, "%s: NULL baton from %s\n", __FUNCTION__, caller);
+        return;
+    }
     seriesPassBaton(&baton->current, baton, caller);
 }
 
@@ -1308,7 +1314,7 @@ void
 pmSeriesDiscoverClosed(pmDiscoverEvent *event, void *arg)
 {
     pmDiscover		*p = (pmDiscover *)event->data;
-    seriesLoadBaton	*baton = p->baton;
+    seriesLoadBaton	*baton = p ? p->baton : NULL; 
 
     (void)arg;
 
