@@ -13,6 +13,12 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
+ *
+ * Debugging options
+ * appl0	initialization, configfile parsing and log file
+ * 		processing
+ * appl1	timer operations, log file probing
+ * appl2	IPC with worker processes, log lines processed
  */
 
 #include "weblog.h"
@@ -100,6 +106,7 @@ usage(void)
 \n\
 Options\n\
   -C            check configuration and exit\n\
+  -D debug      set debug options, see pmdbg(1)\n\
   -d domain	PMDA domain number\n\
   -h helpfile   get help text from helpfile rather than default path\n\
   -i port	expect PMCD to connect on given inet port (number or name)\n\
@@ -327,15 +334,23 @@ receivePDUs(pmdaInterface *dispatch)
 
     for (;;) {
 
-	FD_SET(fileno(stdin), &rfds);
+	/*
+	 * avoid gcc warning: array subscript is above array bounds
+	 * on NetBSD
+	 */
+	if (fileno(stdin) >= 0)
+	    FD_SET(fileno(stdin), &rfds);
+	else {
+	    logmessage(LOG_CRIT, "receivePDUs: fileno(stdin) = %d!\n",  fileno(stdin));
+	}
 	pmtimevalNow(&timeout);
 	timeout.tv_usec = 0;
 	interval = (time_t)wl_refreshDelay - (timeout.tv_sec % (time_t)wl_refreshDelay);
 	timeout.tv_sec = interval;
 
 	if (pmDebugOptions.appl1)
-	    logmessage(LOG_DEBUG, "Select set for %d seconds\n", 
-			 interval);
+	    logmessage(LOG_DEBUG, "Select set for %ld seconds\n", 
+			 (long)interval);
 
 	sts = select(nfds, &rfds, (fd_set*)0, (fd_set*)0, &timeout);
 	if (sts < 0) {
@@ -459,7 +474,7 @@ main(int argc, char **argv)
     FILE		*tmpFp = (FILE*)0;
 
     pmdaInterface	desc;
-    struct timeval	delta;
+    struct timespec	delta;
 
     struct {
 	int		*argPos;
